joop.flask — joop 0.0.1 documentation

# joop.flask

Flask application initialization module for joop.

This is used for example, development, and testing purposes. This module initializes a Flask application and configures it with the joop Jinja2 environment. That is important. ^^^ We are not using the default Jinja2 env, and that is intentional. This is the place to register example Flask views to the application.

joop.flask.app

  The Flask application instance.

  Type:

    Flask

Modules:

Modules

`example` | This is the default place to turn example or other View definitions into
`flask_view` | Flask view integration for joop.